import Vue from 'vue'
const wsUrl = 'wss://api.chzb9.com/wss'
let socket = null
const heartCheck = {
    timeout: 40000,
    timeoutObj: null,
    reset() {
        clearTimeout(this.timeoutObj)
        this.start()
    },
    start() {
        this.timeoutObj = setTimeout(function() {
            emitter.send({ type: "heartbeat" })
        }, this.timeout)
    },
    clear() {
        clearTimeout(this.timeoutObj)
    },
}
const emitter = new Vue({
    methods: {
        send(message) {
            if (socket.readyState === 1) {
                socket.send(JSON.stringify(message))
            }
        },
        connect() {
            socket = new WebSocket(wsUrl)
            socket.onopen = function() {
                console.log('open')
                heartCheck.start()
            }
            socket.onmessage = function(msg) {
                emitter.$emit('message', msg.data)
                if (msg.code === 101) {
                    heartCheck.reset()
                }
                if (msg.code === 100) {
                    emitter.$emit('message', msg.data)
                }
            }
            socket.onerror = function(err) {
                emitter.$emit('error', err)
            }
            socket.onclose = function() {
                console.log('close')
                emitter.connect()
            }
        },
        close() {
            heartCheck.clear()
            socket.close()
        },
    },
})

export default emitter